@@ -20,6 +20,7 @@
 
 """
 
+from collections import namedtuple
 from collections import OrderedDict
 import copy
 import datetime
@@ -28,7 +29,6 @@ import inspect
 import logging
 import mock
 from oslo_utils import versionutils as vutils
-import six
 
 import fixtures
 from oslo_versionedobjects import base
@@ -131,7 +131,7 @@ class FakeIndirectionAPI(base.VersionedObjectIndirectionAPI):
         objinst = self._ser.deserialize_entity(
             context, self._ser.serialize_entity(
                 context, objinst))
-        objmethod = six.text_type(objmethod)
+        objmethod = str(objmethod)
         args, kwargs = self._canonicalize_args(context, args, kwargs)
         original = objinst.obj_clone()
         with mock.patch('oslo_versionedobjects.base.VersionedObject.'
@@ -143,9 +143,9 @@ class FakeIndirectionAPI(base.VersionedObjectIndirectionAPI):
 
     def object_class_action(self, context, objname, objmethod, objver,
                             args, kwargs):
-        objname = six.text_type(objname)
-        objmethod = six.text_type(objmethod)
-        objver = six.text_type(objver)
+        objname = str(objname)
+        objmethod = str(objmethod)
+        objver = str(objver)
         args, kwargs = self._canonicalize_args(context, args, kwargs)
         cls = base.VersionedObject.obj_class_from_name(objname, objver)
         with mock.patch('oslo_versionedobjects.base.VersionedObject.'
@@ -158,10 +158,9 @@ class FakeIndirectionAPI(base.VersionedObjectIndirectionAPI):
 
     def object_class_action_versions(self, context, objname, objmethod,
                                      object_versions, args, kwargs):
-        objname = six.text_type(objname)
-        objmethod = six.text_type(objmethod)
-        object_versions = {six.text_type(o): six.text_type(v)
-                           for o, v in object_versions.items()}
+        objname = str(objname)
+        objmethod = str(objmethod)
+        object_versions = {str(o): str(v) for o, v in object_versions.items()}
         args, kwargs = self._canonicalize_args(context, args, kwargs)
         objver = object_versions[objname]
         cls = base.VersionedObject.obj_class_from_name(objname, objver)
@@ -198,6 +197,31 @@ class ObjectHashMismatch(Exception):
             ','.join(set(self.expected.keys() + self.actual.keys())))
 
 
+CompatArgSpec = namedtuple(
+    'ArgSpec', ('args', 'varargs', 'keywords', 'defaults'))
+
+
+def get_method_spec(method):
+    """Get a stable and compatible method spec.
+
+    Newer features in Python3 (kw-only arguments and annotations) are
+    not supported or representable with inspect.getargspec() but many
+    object hashes are already recorded using that method. This attempts
+    to return something compatible with getargspec() when possible (i.e.
+    when those features are not used), and otherwise just returns the
+    newer getfullargspec() representation.
+    """
+    fullspec = inspect.getfullargspec(method)
+    if any([fullspec.kwonlyargs, fullspec.kwonlydefaults,
+            fullspec.annotations]):
+        # Method uses newer-than-getargspec() features, so return the
+        # newer full spec
+        return fullspec
+    else:
+        return CompatArgSpec(fullspec.args, fullspec.varargs,
+                             fullspec.varkw, fullspec.defaults)
+
+
 class ObjectVersionChecker(object):
     def __init__(self, obj_classes=base.VersionedObjectRegistry.obj_classes()):
         self.obj_classes = obj_classes
@@ -229,7 +253,7 @@ class ObjectVersionChecker(object):
                or isinstance(thing, classmethod):
                 method = self._find_remotable_method(obj_class, thing)
                 if method:
-                    methods.append((name, inspect.getargspec(method)))
+                    methods.append((name, get_method_spec(method)))
         methods.sort()
         # NOTE(danms): Things that need a version bump are any fields
         # and their types, or the signatures of any remotable methods.
@@ -247,7 +271,7 @@ class ObjectVersionChecker(object):
             relevant_data += extra_data_func(obj_class)
 
         fingerprint = '%s-%s' % (obj_class.VERSION, hashlib.md5(
-            six.binary_type(repr(relevant_data).encode())).hexdigest())
+            bytes(repr(relevant_data).encode())).hexdigest())
         return fingerprint
 
     def get_hashes(self, extra_data_func=None):
